searchData={"items":[{"type":"module","doc":"A Req plugin for ClickHouse.\n\nBy default, `ReqCH` will use TSV as the default output format.\nTo change that, see the `new/2` docs for details.","title":"ReqCH","ref":"ReqCH.html"},{"type":"function","doc":"Builds a new `%Req.Request{}` for ClickHouse requests.","title":"ReqCH.new/1","ref":"ReqCH.html#new/1"},{"type":"function","doc":"This function can receive any option that `Req.new/1` accepts,\nplus the ones described below.\n\nTo set a new endpoint, use the `:base_url` option from `Req`.\nIt is by default \"http://localhost:8123\".\n\n  * `:format` - Optional. The format of the response. Default is `:tsv`.\n    This option accepts `:tsv`, `:csv`, `:json` or `:explorer` as atoms.\n\n    It also accepts all formats described in the https://clickhouse.com/docs/en/interfaces/formats page.\n    Use plain strings for these formats.\n\n    The `:explorer` format is special, and will build an Explorer dataframe\n    in case the `:explorer` dependency is installed.\n\n  * `:database` - Optional. The database to use in the queries.\n    Default is `nil`.","title":"Options - ReqCH.new/1","ref":"ReqCH.html#new/1-options"},{"type":"function","doc":"After setting a default database, one can make a request directly:\n\n    iex> req = ReqCH.new(database: \"system\")\n    iex> Req.post!(req, body: \"SELECT number + 1 FROM numbers LIMIT 3\").body\n    \"1\\n2\\n3\\n\"\n\nIt's also possible to make a query using `Req.get/2`:\n\n    iex> req = ReqCH.new(database: \"system\")\n    iex> Req.get!(req, params: [query: \"SELECT number + 1 FROM numbers LIMIT 3\"]).body\n    \"1\\n2\\n3\\n\"\n\nIn case the server needs authentication, it's possible to use `Req` options for that.\n\n    iex> req = ReqCH.new(base_url: \"http://example.org:8123\", auth: {:basic, \"user:pass\"})\n    iex> Req.post!(req, body: \"SELECT number FROM system.numbers LIMIT 3\").body\n    \"0\\n1\\n2\\n\"","title":"Examples - ReqCH.new/1","ref":"ReqCH.html#new/1-examples"},{"type":"function","doc":"Performs a query against the ClickHouse API.\n\nThis version receives a `Req.Request.t()`, so it won't\ncreate a new one from scratch.\n\nBy default, it will use the `http://localhost:8123` as `:base_url`.\nYou can change that either providing in your Req request, or in passing\ndown in the options.\nSee `new/1` for the options. Like that function, `query/4` accepts any\noption that `Req.new/1` accepts.","title":"ReqCH.query/4","ref":"ReqCH.html#query/4"},{"type":"function","doc":"Queries can be performed using both `Req.get/2` or `Req.post/2`, but GET\nis \"read-only\" and commands like `CREATE` or `INSERT` cannot be used with it.\nFor that reason, by default we perform a `POST` request.\n\nA plain query:\n\n    iex> req = ReqCH.new(database: \"system\")\n    iex> {:ok, response} = ReqCH.query(req, \"SELECT number FROM numbers LIMIT 3\")\n    iex> response.body\n    \"0\\n1\\n2\\n\"\n\nWith a specific format:\n\n    iex> req = ReqCH.new(database: \"system\")\n    iex> {:ok, response} = ReqCH.query(req, \"SELECT number FROM numbers LIMIT 3\", [], [format: :explorer])\n    iex> response.body\n    #Explorer.DataFrame \n\n Passing SQL params:\n\n    iex> req = ReqCH.new(database: \"system\")\n    iex> {:ok, response} = ReqCH.query(req, \"SELECT number FROM numbers WHERE number > {num:UInt8} LIMIT 3\", [num: 5], [])\n    iex> response.body\n    \"6\\n7\\n8\\n\"\n\nThis function can accept `Req` options, as well as mixing them with `ReqCH` options:\n\n    iex> opts = [base_url: \"http://example.org:8123\", database: \"system\", auth: {:basic, \"user:pass\"}]\n    iex> {:ok, response} = ReqCH.query(ReqCH.new(), \"SELECT number FROM numbers LIMIT 3\", [], opts)\n    iex> response.body\n    \"0\\n1\\n2\\n\"","title":"Examples - ReqCH.query/4","ref":"ReqCH.html#query/4-examples"},{"type":"function","doc":"Same as `query/4`, but raises in case of error.","title":"ReqCH.query!/4","ref":"ReqCH.html#query!/4"},{"type":"extras","doc":"# ReqCH\n\n[![Docs](https://img.shields.io/badge/hex.pm-docs-8e7ce6.svg)](https://hexdocs.pm/req_ch)\n[![Hex pm](http://img.shields.io/hexpm/v/req_ch.svg?style=flat&color=blue)](https://hex.pm/packages/req_ch)\n\nA [Req](https://github.com/wojtekmach/req) plugin for [ClickHouse](https://clickhouse.com/).","title":"ReqCH","ref":"readme.html"},{"type":"extras","doc":"Assuming that you have a ClickHouse server running on localhost, this code is going to run:\n\n```elixir\nMix.install([\n  {:req_ch, \"~> 0.1.0\"}\n])\n\nreq = ReqCH.new(database: \"system\")\n\nReqCH.query!(req, \"SELECT number FROM numbers LIMIT 5\").body\n# => \"0\\n1\\n2\\n3\\n4\\n\"\n\nReqCH.query!(req, \"SELECT number FROM numbers WHERE number > {num:UInt8} LIMIT 5\", [num: 12]).body\n# => \"13\\n14\\n15\\n16\\n17\\n\"\n```\n\nIt's also possible to return `Explorer` dataframes, if the `:explorer` package is installed\nand the `:explorer` format is used:\n\n```elixir\nMix.install([\n  {:req_ch, \"~> 0.1.0\"},\n  {:explorer, \"~> 0.10.0\"}\n])\n\nreq = ReqCH.new(database: \"system\")\n\nReqCH.query!(req, \"SELECT number, number - 2 as less_two FROM numbers LIMIT 5\", [], [format: :explorer]).body\n# => #Explorer.DataFrame<\n#   Polars[5 x 2]\n#   number u64 [0, 1, 2, 3, 4]\n#   less_two s64 [-2, -1, 0, 1, 2]\n# >\n```\n\nSee the [documentation](https://hexdocs.pm/req_ch) for details.","title":"Usage - ReqCH","ref":"readme.html#usage"},{"type":"extras","doc":"Copyright (C) 2024 Dashbit\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","title":"License - ReqCH","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}